==> symfony_5.4.4+dfsg.orig.tar.xz: symfony-5.4.4/src/Symfony/Component/Intl/Resources/data/languages/ky.php <==
<?php

return [
    'Names' => [
        'aa' => 'афарча',
        'ab' => 'абхазча',
        'ace' => 'ачехче',
        'ada' => 'адаңмече',
        'ady' => 'адыгейче',
        'af' => 'африкаанча',
        'agq' => 'агемче',
        'ain' => 'айнуча',
        'ak' => 'аканча',
        'ale' => 'алеутча',
        'alt' => 'түштүк алтайча',
        'am' => 'амхарча',
        'an' => 'арагончо',
        'anp' => 'ангикача',
        'ar' => 'арабча',
        'arn' => 'мапучече',
        'arp' => 'арапахочо',
        'as' => 'ассамча',
        'asa' => 'асуча',
        'ast' => 'астурийче',
        'av' => 'аварикче',
        'awa' => 'авадхиче',
        'ay' => 'аймарача',
        'az' => 'азербайжанча',
        'ba' => 'башкырча',
        'ban' => 'баличе',
        'bas' => 'басаача',
        'be' => 'беларусча',
        'bem' => 'бембача',
        'bez' => 'бенача',
        'bg' => 'болгарча',
        'bgn' => 'чыгыш балучиче',
        'bho' => 'бхожпуриче',
        'bi' => 'бисламача',
        'bin' => 'биниче',
        'bla' => 'сиксикача',
        'bm' => 'бамбарача',
        'bn' => 'бангладешче',
        'bo' => 'тибетче',
        'br' => 'бретончо',
        'brx' => 'бодочо',
        'bs' => 'боснийче',
        'bug' => 'бугийче',
        'byn' => 'блинче',
        'ca' => 'каталончо',
        'ccp' => 'чакма',
        'ce' => 'чеченче',
        'ceb' => 'себуанча',
        'cgg' => 'чигача',
        'ch' => 'чаморрочо',
        'chk' => 'чуукиче',
        'chm' => 'мариче',
        'cho' => 'чокточо',
        'chr' => 'черокиче',
        'chy' => 'шайеннче',
        'ckb' => 'борбордук курдча',
        'co' => 'корсиканча',
        'crs' => 'сеселва креол французча',
        'cs' => 'чехче',
        'cu' => 'чиркөө славянча',
        'cv' => 'чувашча',
        'cy' => 'уелшче',
        'da' => 'датча',
        'dak' => 'дакотача',
        'dar' => 'даргинче',
        'dav' => 'таитача',
        'de' => 'немисче',
        'dgr' => 'догрибче',
        'dje' => 'зармача',
        'doi' => 'догриче',
        'dsb' => 'төмөнкү сорбианча',
        'dua' => 'дуалача',
        'dv' => 'дивехиче',
        'dyo' => 'жола-фониче',
        'dz' => 'жонгуча',
        'dzg' => 'дазагача',
        'ebu' => 'эмбуча',
        'ee' => 'эбече',
        'efi' => 'эфикче',
        'eka' => 'экажукча',
        'el' => 'грекче',
        'en' => 'англисче',
        'eo' => 'эсперанто',
        'es' => 'испанча',
        'et' => 'эстончо',
        'eu' => 'баскча',
        'ewo' => 'эвондочо',
        'fa' => 'фарсча',
        'ff' => 'фулача',
        'fi' => 'финче',
        'fil' => 'филипинче',
        'fj' => 'фижиче',
        'fo' => 'фарерче',
        'fon' => 'фончо',
        'fr' => 'французча',
        'fur' => 'фриулча',
        'fy' => 'батыш фризче',
        'ga' => 'ирландча',
        'gaa' => 'гача',
        'gag' => 'гагаузча',
        'gan' => 'Гань Кытайча',
        'gd' => 'шотладиялык гелча',
        'gez' => 'гиизче',
        'gil' => 'гилбертче',
        'gl' => 'галисияча',
        'gn' => 'гуараниче',
        'gor' => 'горонталочо',
        'gsw' => 'немисче (Швейцария)',
        'gu' => 'гужаратча',
        'guz' => 'гусиче',
        'gv' => 'мэнксыча',
        'gwi' => 'гвичинче',
        'ha' => 'хаусача',
        'hak' => 'Хакка кытайча',
        'haw' => 'гавайча',
        'he' => 'ивритче',
        'hi' => 'хиндиче',
        'hil' => 'хилигайнончо',
        'hmn' => 'хмонгчо',
        'hr' => 'хорватча',
        'hsb' => 'жогорку сорбианча',
        'hsn' => 'Сянь Кытайча',
        'ht' => 'гаитиче',
        'hu' => 'венгерче',
        'hup' => 'хупача',
        'hy' => 'армянча',
        'hz' => 'герерочо',
        'ia' => 'интерлингва',
        'iba' => 'ибанча',
        'ibb' => 'ибибиочо',
        'id' => 'индонезияча',
        'ig' => 'игбочо',
        'ii' => 'сычуань йиче',
        'ilo' => 'илокочо',
        'inh' => 'ингушча',
        'io' => 'идочо',
        'is' => 'исландча',
        'it' => 'италиянча',
        'iu' => 'инуктитутча',
        'ja' => 'жапончо',
        'jbo' => 'ложбанча',
        'jgo' => 'нгомбача',
        'jmc' => 'мачамече',
        'jv' => 'жаванизче',
        'ka' => 'грузинче',
        'kab' => 'кабылча',
        'kac' => 'кахинче',
        'kaj' => 'джуча',
        'kam' => 'камбача',
        'kbd' => 'кабардинче',
        'kcg' => 'тяпча',
        'kde' => 'макондече',
        'kea' => 'кабувердиче',
        'kfo' => 'корочо',
        'kha' => 'хасиче',
        'khq' => 'койра чиниче',
        'ki' => 'кикуйиче',
        'kj' => 'куаньямача',
        'kk' => 'казакча',
        'kkj' => 'какочо',
        'kl' => 'калаалисутча',
        'kln' => 'каленжиче',
        'km' => 'кмерче',
        'kmb' => 'кимбундуча',
        'kn' => 'каннадача',
        'ko' => 'корейче',
        'koi' => 'коми-пермякча',
        'kok' => 'конканиче',
        'kpe' => 'кпеллече',
        'kr' => 'кануриче',
        'krc' => 'карачай-балкарча',
        'krl' => 'карелче',
        'kru' => 'курухча',
        'ks' => 'кашмирче',
        'ksb' => 'шамабалача',
        'ksf' => 'бафияча',
        'ksh' => 'колоньяча',
        'ku' => 'курдча',
        'kum' => 'кумыкча',
        'kv' => 'комиче',
        'kw' => 'корнишче',
        'ky' => 'кыргызча',
        'la' => 'латынча',
        'lad' => 'ладиночо',
        'lag' => 'лангиче',
        'lb' => 'люксембургча',
        'lez' => 'лезгинче',
        'lg' => 'гандача',
        'li' => 'лимбургиче',
        'lkt' => 'лакотача',
        'ln' => 'лингалача',
        'lo' => 'лаочо',
        'loz' => 'лозиче',
        'lrc' => 'түндүк луриче',
        'lt' => 'литовчо',
        'lu' => 'луба-катангача',
        'lua' => 'луба-лулуача',
        'lun' => 'лундача',
        'luo' => 'луочо',
        'lus' => 'мизочо',
        'luy' => 'лухияча',
        'lv' => 'латышча',
        'mad' => 'мадурисче',
        'mag' => 'магахиче',
        'mai' => 'маитиличе',
        'mak' => 'макасарча',
        'mas' => 'масайча',
        'mdf' => 'мокшача',
        'men' => 'мендече',
        'mer' => 'меруча',
        'mfe' => 'морисианча',
        'mg' => 'малагасча',
        'mgh' => 'макуача',
        'mgo' => 'метача',
        'mh' => 'маршаллча',
        'mi' => 'маориче',
        'mic' => 'микмакча',
        'min' => 'минанкабауча',
        'mk' => 'македончо',
        'ml' => 'малайаламча',
        'mn' => 'монголчо',
        'mni' => 'манипуриче',
        'moh' => 'мохаукча',
        'mos' => 'моссиче',
        'mr' => 'маратиче',
        'ms' => 'малайча',
        'mt' => 'малтизче',
        'mua' => 'мундангча',
        'mus' => 'крикче',
        'mwl' => 'мирандизче',
        'my' => 'бурмача',
        'myv' => 'эрзянча',
        'mzn' => 'мазандераниче',
        'na' => 'науруча',
        'nap' => 'неополитанча',
        'naq' => 'намача',
        'nb' => 'норвежче (букмал)',
        'nd' => 'түндүк ндыбелче',
        'nds' => 'төмөнкү немисче',
        'ne' => 'непалча',
        'new' => 'невариче',
        'ng' => 'ндонгача',
        'nia' => 'ниасча',
        'niu' => 'ньюанча',
        'nl' => 'голландча',
        'nmg' => 'квасиочо',
        'nn' => 'норвежче (нинорск)',
        'nnh' => 'нгимбунча',
        'no' => 'норвежче',
        'nog' => 'ногайча',
        'nqo' => 'нкочо',
        'nr' => 'түштүк ндебелече',
        'nso' => 'түндүк соточо',
        'nus' => 'нуерче',
        'nv' => 'наваджочо',
        'ny' => 'ньянджача',
        'nyn' => 'ныйанколчо',
        'oc' => 'окситанча',
        'om' => 'оромочо',
        'or' => 'орияча',
        'os' => 'осетинче',
        'pa' => 'пунжабиче',
        'pag' => 'пангасиче',
        'pam' => 'пампангача',
        'pap' => 'папиаменточо',
        'pau' => 'палауанча',
        'pcm' => 'аргындашкан тил (Нигерия)',
        'pl' => 'полякча',
        'prg' => 'пруссча',
        'ps' => 'пуштуча',
        'pt' => 'португалча',
        'qu' => 'кечуача',
        'quc' => 'кичече',
        'rap' => 'рапаньюча',
        'rar' => 'раротонгача',
        'rhg' => 'рохинжача',
        'rm' => 'романшча',
        'rn' => 'рундиче',
        'ro' => 'румынча',
        'rof' => 'ромбочо',
        'ru' => 'орусча',
        'rup' => 'аромунча',
        'rw' => 'руандача',
        'rwk' => 'руача',
        'sa' => 'санскритче',
        'sad' => 'сандавече',
        'sah' => 'сахача',
        'saq' => 'самбуруча',
        'sat' => 'санталиче',
        'sba' => 'нгамбайча',
        'sbp' => 'сангуча',
        'sc' => 'сардинче',
        'scn' => 'сицилийче',
        'sco' => 'шотландча',
        'sd' => 'синдхиче',
        'sdh' => 'түштүк курдча',
        'se' => 'түндүк саамиче',
        'seh' => 'сенача',
        'ses' => 'койраборо сенниче',
        'sg' => 'сангочо',
        'sh' => 'серб-хорват',
        'shi' => 'ташелитче',
        'shn' => 'шанча',
        'si' => 'сингалача',
        'sk' => 'словакча',
        'sl' => 'словенче',
        'sm' => 'самоанча',
        'sma' => 'түштүк саамиче',
        'smj' => 'луле саамиче',
        'smn' => 'инари саамиче',
        'sms' => 'сколт саамиче',
        'sn' => 'шонача',
        'snk' => 'сонинкече',
        'so' => 'сомаличе',
        'sq' => 'албанча',
        'sr' => 'сербче',
        'srn' => 'сранан тонгочо',
        'ss' => 'сватиче',
        'ssy' => 'сахочо',
        'st' => 'сесоточо',
        'su' => 'сунданча',
        'suk' => 'сукумача',
        'sv' => 'шведче',
        'sw' => 'суахиличе',
        'swb' => 'коморчо',
        'syr' => 'сирияча',
        'ta' => 'тамилче',
        'te' => 'телугуча',
        'tem' => 'тимнече',
        'teo' => 'тесочо',
        'tet' => 'тетумча',
        'tg' => 'тажикче',
        'th' => 'тайча',
        'ti' => 'тигриниача',
        'tig' => 'тигрече',
        'tk' => 'түркмөнчө',
        'tlh' => 'клингончо',
        'tn' => 'тсванача',
        'to' => 'тонгача',
        'tpi' => 'ток-писинче',
        'tr' => 'түркчө',
        'trv' => 'тарокочо',
        'ts' => 'тсонгача',
        'tt' => 'татарча',
        'tum' => 'тумбукача',
        'tvl' => 'тувалуча',
        'tw' => 'тви',
        'twq' => 'тасабакча',
        'ty' => 'таитиче',
        'tyv' => 'тувинче',
        'tzm' => 'борбордук Атлас тамазигтче',
        'udm' => 'удмуртча',
        'ug' => 'уйгурча',
        'uk' => 'украинче',
        'umb' => 'умбундуча',
        'ur' => 'урдуча',
        'uz' => 'өзбекче',
        'vai' => 'вайиче',
        've' => 'вендача',
        'vi' => 'вьетнамча',
        'vo' => 'волапюкча',
        'vun' => 'вунжочо',
        'wa' => 'валлончо',
        'wae' => 'валцерче',
        'wal' => 'вольяттача',
        'war' => 'варайча',
        'wbp' => 'ворлпириче',
        'wo' => 'уолофчо',
        'xal' => 'калмыкча',
        'xh' => 'косача',
        'xog' => 'согача',
        'yav' => 'янгбенче',
        'ybb' => 'йембача',
        'yi' => 'идишче',
        'yo' => 'йорубача',
        'yue' => 'кантончо',
        'zgh' => 'марокко тамазигт адабий тилинде',
        'zh' => 'кытайча',
        'zu' => 'зулуча',
        'zun' => 'зуниче',
        'zza' => 'зазача',
    ],
    'LocalizedNames' => [
        'ar_001' => 'азыркы адабий араб тилинде',
        'de_CH' => 'адабий немисче (Швейцария)',
        'en_US' => 'англисче (Америка Кошмо Штаттары)',
        'es_ES' => 'испанча (Европа)',
        'fa_AF' => 'дари',
        'nds_NL' => 'төмөнкү саксончо',
        'nl_BE' => 'фламандча',
        'pt_PT' => 'португалча (Европа)',
        'ro_MD' => 'молдованча',
        'sw_CD' => 'конго суахаличе',
        'zh_Hans' => 'кытайча (жөнөкөйлөштүрүлгөн)',
        'zh_Hant' => 'кытайча (салттуу)',
    ],
];

==> symfony_5.4.23+dfsg.orig.tar.xz: symfony-5.4.23/src/Symfony/Component/Intl/Resources/data/languages/ky.php <==
<?php

return [
    'Names' => [
        'aa' => 'афарча',
        'ab' => 'абхазча',
        'ace' => 'ачехче',
        'ada' => 'адаңмече',
        'ady' => 'адыгейче',
        'af' => 'африкаанча',
        'agq' => 'агемче',
        'ain' => 'айнуча',
        'ak' => 'аканча',
        'ale' => 'алеутча',
        'alt' => 'түштүк алтайча',
        'am' => 'амхарча',
        'an' => 'арагончо',
        'ann' => 'оболочо (Нигерия)',
        'anp' => 'ангикача',
        'ar' => 'арабча',
        'arn' => 'мапучече',
        'arp' => 'арапахочо',
        'ars' => 'арабча (нежди диалекти)',
        'as' => 'ассамча',
        'asa' => 'асуча',
        'ast' => 'астурийче',
        'atj' => 'атикамекче',
        'av' => 'аварикче',
        'awa' => 'авадхиче',
        'ay' => 'аймарача',
        'az' => 'азербайжанча',
        'ba' => 'башкырча',
        'ban' => 'баличе',
        'bas' => 'басаача',
        'be' => 'беларусча',
        'bem' => 'бембача',
        'bez' => 'бенача',
        'bg' => 'болгарча',
        'bgn' => 'чыгыш балучиче',
        'bho' => 'бхожпуриче',
        'bi' => 'бисламача',
        'bin' => 'биниче',
        'bla' => 'сиксикача',
        'bm' => 'бамбарача',
        'bn' => 'бангладешче',
        'bo' => 'тибетче',
        'br' => 'бретончо',
        'brx' => 'бодочо',
        'bs' => 'боснийче',
        'bug' => 'бугийче',
        'byn' => 'блинче',
        'ca' => 'каталончо',
        'cay' => 'каюгиче',
        'ccp' => 'чакма',
        'ce' => 'чеченче',
        'ceb' => 'себуанча',
        'cgg' => 'чигача',
        'ch' => 'чаморрочо',
        'chk' => 'чуукиче',
        'chm' => 'мариче',
        'cho' => 'чокточо',
        'chp' => 'чипевайанча',
        'chr' => 'черокиче',
        'chy' => 'шайеннче',
        'ckb' => 'борбордук курдча',
        'clc' => 'чилкотинче (британдык колумбиядагы аймак)',
        'co' => 'корсиканча',
        'crg' => 'мичифче (индей тили)',
        'crj' => 'түштүк-чыгыш криче (индей тили)',
        'crk' => 'өрөөндүк криче (индей тили)',
        'crl' => 'чыгыш криче (индей тилдери)',
        'crm' => 'муус криче (индей тили)',
        'crr' => 'каролиналык алгонкинче',
        'crs' => 'сеселва креол французча',
        'cs' => 'чехче',
        'csw' => 'суампи криче (индей тили)',
        'cu' => 'чиркөө славянча',
        'cv' => 'чувашча',
        'cy' => 'уелшче',
        'da' => 'датча',
        'dak' => 'дакотача',
        'dar' => 'даргинче',
        'dav' => 'таитача',
        'de' => 'немисче',
        'dgr' => 'догрибче',
        'dje' => 'зармача',
        'doi' => 'догриче',
        'dsb' => 'төмөнкү сорбианча',
        'dua' => 'дуалача',
        'dv' => 'дивехиче',
        'dyo' => 'жола-фониче',
        'dz' => 'жонгуча',
        'dzg' => 'дазагача',
        'ebu' => 'эмбуча',
        'ee' => 'эбече',
        'efi' => 'эфикче',
        'eka' => 'экажукча',
        'el' => 'грекче',
        'en' => 'англисче',
        'eo' => 'эсперанто',
        'es' => 'испанча',
        'et' => 'эстончо',
        'eu' => 'баскча',
        'ewo' => 'эвондочо',
        'fa' => 'фарсча',
        'ff' => 'фулача',
        'fi' => 'финче',
        'fil' => 'филипинче',
        'fj' => 'фижиче',
        'fo' => 'фарерче',
        'fon' => 'фончо',
        'fr' => 'французча',
        'frc' => 'французча (кажун диалектиси)',
        'frr' => 'түндүк фризче (евразиялык тилдер)',
        'fur' => 'фриулча',
        'fy' => 'батыш фризче',
        'ga' => 'ирландча',
        'gaa' => 'гача',
        'gag' => 'гагаузча',
        'gan' => 'Гань Кытайча',
        'gd' => 'шотладиялык гелча',
        'gez' => 'гиизче',
        'gil' => 'гилбертче',
        'gl' => 'галисияча',
        'gn' => 'гуараниче',
        'gor' => 'горонталочо',
        'gsw' => 'немисче (Швейцария)',
        'gu' => 'гужаратча',
        'guz' => 'гусиче',
        'gv' => 'мэнксыча',
        'gwi' => 'гвичинче',
        'ha' => 'хаусача',
        'hai' => 'хайдача',
        'hak' => 'Хакка кытайча',
        'haw' => 'гавайча',
        'hax' => 'хайдача (индей тили)',
        'he' => 'ивритче',
        'hi' => 'хиндиче',
        'hil' => 'хилигайнончо',
        'hmn' => 'хмонгчо',
        'hr' => 'хорватча',
        'hsb' => 'жогорку сорбианча',
        'hsn' => 'Сянь Кытайча',
        'ht' => 'гаитиче',
        'hu' => 'венгерче',
        'hup' => 'хупача',
        'hur' => 'халкомелемче (индей тили)',
        'hy' => 'армянча',
        'hz' => 'герерочо',
        'ia' => 'интерлингва',
        'iba' => 'ибанча',
        'ibb' => 'ибибиочо',
        'id' => 'индонезияча',
        'ig' => 'игбочо',
        'ii' => 'сычуань йиче',
        'ikt' => 'инуктитутча (Канада)',
        'ilo' => 'илокочо',
        'inh' => 'ингушча',
        'io' => 'идочо',
        'is' => 'исландча',
        'it' => 'италиянча',
        'iu' => 'инуктитутча',
        'ja' => 'жапончо',
        'jbo' => 'ложбанча',
        'jgo' => 'нгомбача',
        'jmc' => 'мачамече',
        'jv' => 'жаванизче',
        'ka' => 'грузинче',
        'kab' => 'кабылча',
        'kac' => 'кахинче',
        'kaj' => 'джуча',
        'kam' => 'камбача',
        'kbd' => 'кабардинче',
        'kcg' => 'тяпча',
        'kde' => 'макондече',
        'kea' => 'кабувердиче',
        'kfo' => 'корочо',
        'kgp' => 'кайнгангча (индей тили)',
        'kha' => 'хасиче',
        'khq' => 'койра чиниче',
        'ki' => 'кикуйиче',
        'kj' => 'куаньямача',
        'kk' => 'казакча',
        'kkj' => 'какочо',
        'kl' => 'калаалисутча',
        'kln' => 'каленжиче',
        'km' => 'кмерче',
        'kmb' => 'кимбундуча',
        'kn' => 'каннадача',
        'ko' => 'корейче',
        'koi' => 'коми-пермякча',
        'kok' => 'конканиче',
        'kpe' => 'кпеллече',
        'kr' => 'кануриче',
        'krc' => 'карачай-балкарча',
        'krl' => 'карелче',
        'kru' => 'курухча',
        'ks' => 'кашмирче',
        'ksb' => 'шамабалача',
        'ksf' => 'бафияча',
        'ksh' => 'колоньяча',
        'ku' => 'курдча',
        'kum' => 'кумыкча',
        'kv' => 'комиче',
        'kw' => 'корнишче',
        'kwk' => 'кваквалача (индей тили)',
        'ky' => 'кыргызча',
        'la' => 'латынча',
        'lad' => 'ладиночо',
        'lag' => 'лангиче',
        'lb' => 'люксембургча',
        'lez' => 'лезгинче',
        'lg' => 'гандача',
        'li' => 'лимбургиче',
        'lil' => 'лиллуэтче (индей тили)',
        'lkt' => 'лакотача',
        'ln' => 'лингалача',
        'lo' => 'лаочо',
        'lou' => 'луизиана креолчо',
        'loz' => 'лозиче',
        'lrc' => 'түндүк луриче',
        'lsm' => 'саамиача (Уганда, Кения)',
        'lt' => 'литовчо',
        'lu' => 'луба-катангача',
        'lua' => 'луба-лулуача',
        'lun' => 'лундача',
        'luo' => 'луочо',
        'lus' => 'мизочо',
        'luy' => 'лухияча',
        'lv' => 'латышча',
        'mad' => 'мадурисче',
        'mag' => 'магахиче',
        'mai' => 'маитиличе',
        'mak' => 'макасарча',
        'mas' => 'масайча',
        'mdf' => 'мокшача',
        'men' => 'мендече',
        'mer' => 'меруча',
        'mfe' => 'морисианча',
        'mg' => 'малагасча',
        'mgh' => 'макуача',
        'mgo' => 'метача',
        'mh' => 'маршаллча',
        'mi' => 'маориче',
        'mic' => 'микмакча',
        'min' => 'минанкабауча',
        'mk' => 'македончо',
        'ml' => 'малайаламча',
        'mn' => 'монголчо',
        'mni' => 'манипуриче',
        'moe' => 'инну-аймунча (индейлер тили)',
        'moh' => 'мохаукча',
        'mos' => 'моссиче',
        'mr' => 'маратиче',
        'ms' => 'малайча',
        'mt' => 'малтизче',
        'mua' => 'мундангча',
        'mus' => 'крикче',
        'mwl' => 'мирандизче',
        'my' => 'бурмача',
        'myv' => 'эрзянча',
        'mzn' => 'мазандераниче',
        'na' => 'науруча',
        'nap' => 'неополитанча',
        'naq' => 'намача',
        'nb' => 'норвежче (букмал)',
        'nd' => 'түндүк ндыбелче',
        'nds' => 'төмөнкү немисче',
        'ne' => 'непалча',
        'new' => 'невариче',
        'ng' => 'ндонгача',
        'nia' => 'ниасча',
        'niu' => 'ньюанча',
        'nl' => 'голландча',
        'nmg' => 'квасиочо',
        'nn' => 'норвежче (нинорск)',
        'nnh' => 'нгимбунча',
        'no' => 'норвежче',
        'nog' => 'ногайча',
        'nqo' => 'нкочо',
        'nr' => 'түштүк ндебелече',
        'nso' => 'түндүк соточо',
        'nus' => 'нуерче',
        'nv' => 'наваджочо',
        'ny' => 'ньянджача',
        'nyn' => 'ныйанколчо',
        'oc' => 'окситанча',
        'ojb' => 'түндүк-батыш ожибвече (индей тили)',
        'ojc' => 'борбордук ожибвече',
        'ojs' => 'ожи-криче (индей тили)',
        'ojw' => 'батыш ожибвече (индей тили)',
        'oka' => 'оканаганча (Канада)',
        'om' => 'оромочо',
        'or' => 'орияча',
        'os' => 'осетинче',
        'pa' => 'пунжабиче',
        'pag' => 'пангасиче',
        'pam' => 'пампангача',
        'pap' => 'папиаменточо',
        'pau' => 'палауанча',
        'pcm' => 'аргындашкан тил (Нигерия)',
        'pis' => 'пижинче (Соломон Аралдары)',
        'pl' => 'полякча',
        'pqm' => 'малесит-пассамакуоддиче (индей тили)',
        'prg' => 'пруссча',
        'ps' => 'пуштуча',
        'pt' => 'португалча',
        'qu' => 'кечуача',
        'quc' => 'кичече',
        'rap' => 'рапаньюча',
        'rar' => 'раротонгача',
        'rhg' => 'рохинжача',
        'rm' => 'романшча',
        'rn' => 'рундиче',
        'ro' => 'румынча',
        'rof' => 'ромбочо',
        'ru' => 'орусча',
        'rup' => 'аромунча',
        'rw' => 'руандача',
        'rwk' => 'руача',
        'sa' => 'санскритче',
        'sad' => 'сандавече',
        'sah' => 'сахача',
        'saq' => 'самбуруча',
        'sat' => 'санталиче',
        'sba' => 'нгамбайча',
        'sbp' => 'сангуча',
        'sc' => 'сардинче',
        'scn' => 'сицилийче',
        'sco' => 'шотландча',
        'sd' => 'синдхиче',
        'sdh' => 'түштүк курдча',
        'se' => 'түндүк саамиче',
        'seh' => 'сенача',
        'ses' => 'койраборо сенниче',
        'sg' => 'сангочо',
        'sh' => 'серб-хорват',
        'shi' => 'ташелитче',
        'shn' => 'шанча',
        'si' => 'сингалача',
        'sk' => 'словакча',
        'sl' => 'словенче',
        'slh' => 'түштүк лушуцидче (индей тили)',
        'sm' => 'самоанча',
        'sma' => 'түштүк саамиче',
        'smj' => 'луле саамиче',
        'smn' => 'инари саамиче',
        'sms' => 'сколт саамиче',
        'sn' => 'шонача',
        'snk' => 'сонинкече',
        'so' => 'сомаличе',
        'sq' => 'албанча',
        'sr' => 'сербче',
        'srn' => 'сранан тонгочо',
        'ss' => 'сватиче',
        'ssy' => 'сахочо',
        'st' => 'сесоточо',
        'str' => 'стрейтс салишче (индей тили)',
        'su' => 'сунданча',
        'suk' => 'сукумача',
        'sv' => 'шведче',
        'sw' => 'суахиличе',
        'swb' => 'коморчо',
        'syr' => 'сирияча',
        'ta' => 'тамилче',
        'tce' => 'түштүк тутчонече (индей тили)',
        'te' => 'телугуча',
        'tem' => 'тимнече',
        'teo' => 'тесочо',
        'tet' => 'тетумча',
        'tg' => 'тажикче',
        'tgx' => 'тагишче (индей тили)',
        'th' => 'тайча',
        'tht' => 'талтанча (индей тили)',
        'ti' => 'тигриниача',
        'tig' => 'тигрече',
        'tk' => 'түркмөнчө',
        'tlh' => 'клингончо',
        'tli' => 'тлинкитче (индей тили)',
        'tn' => 'тсванача',
        'to' => 'тонгача',
        'tok' => 'токипонача (эксперименталдык тил)',
        'tpi' => 'ток-писинче',
        'tr' => 'түркчө',
        'trv' => 'тарокочо',
        'ts' => 'тсонгача',
        'tt' => 'татарча',
        'ttm' => 'түндүк тутчончо (индей тили)',
        'tum' => 'тумбукача',
        'tvl' => 'тувалуча',
        'tw' => 'тви',
        'twq' => 'тасабакча',
        'ty' => 'таитиче',
        'tyv' => 'тувинче',
        'tzm' => 'борбордук Атлас тамазигтче',
        'udm' => 'удмуртча',
        'ug' => 'уйгурча',
        'uk' => 'украинче',
        'umb' => 'умбундуча',
        'ur' => 'урдуча',
        'uz' => 'өзбекче',
        'vai' => 'вайиче',
        've' => 'вендача',
        'vi' => 'вьетнамча',
        'vo' => 'волапюкча',
        'vun' => 'вунжочо',
        'wa' => 'валлончо',
        'wae' => 'валцерче',
        'wal' => 'вольяттача',
        'war' => 'варайча',
        'wbp' => 'ворлпириче',
        'wo' => 'уолофчо',
        'wuu' => '"У" диалектинде (Кытай)',
        'xal' => 'калмыкча',
        'xh' => 'косача',
        'xog' => 'согача',
        'yav' => 'янгбенче',
        'ybb' => 'йембача',
        'yi' => 'идишче',
        'yo' => 'йорубача',
        'yrl' => 'ньенгатуча (түштүк америка тилдери)',
        'yue' => 'кантончо',
        'zgh' => 'марокко тамазигт адабий тилинде',
        'zh' => 'кытайча',
        'zu' => 'зулуча',
        'zun' => 'зуниче',
        'zza' => 'зазача',
    ],
    'LocalizedNames' => [
        'ar_001' => 'азыркы адабий араб тилинде',
        'de_CH' => 'адабий немисче (Швейцария)',
        'en_US' => 'англисче (Америка Кошмо Штаттары)',
        'es_ES' => 'испанча (Европа)',
        'fa_AF' => 'дари',
        'nds_NL' => 'төмөнкү саксончо',
        'nl_BE' => 'фламандча',
        'pt_PT' => 'португалча (Европа)',
        'ro_MD' => 'молдованча',
        'sw_CD' => 'конго суахаличе',
        'zh_Hans' => 'кытайча (жөнөкөйлөштүрүлгөн)',
        'zh_Hant' => 'кытайча (салттуу)',
    ],
];
